from flask import Blueprint, request, jsonify, send_file, current_app, render_template
import os
from ..utils.helpers import update_config
import logging
import requests

logger = logging.getLogger(__name__)

bp = Blueprint('settings', __name__)

@bp.route("/api/settings/template")
def get_settings_template():
    try:
        return render_template('components/dashboard/settings.html')
    except Exception as e:
        logger.error(f"Error loading settings template: {str(e)}")
        return jsonify({'error': 'Failed to load settings template'}), 500

@bp.route("/api/settings", methods=['GET'])
def get_settings():
    try:
        settings = {
            'API_KEY': current_app.config.get('API_KEY', ''),
            'API_SECRET': current_app.config.get('API_SECRET', ''),
            'BASE_ENDPOINT': current_app.config.get('BASE_ENDPOINT', ''),
            'MESSAGES_PER_PAGE': current_app.config.get('MESSAGES_PER_PAGE', 50),
            'FETCH_INTERVAL_MINUTES': current_app.config.get('FETCH_INTERVAL_MINUTES', 30),
            'DEFAULT_TIMEZONE': current_app.config.get('DEFAULT_TIMEZONE', 'Africa/Nairobi'),
            'IMAGE_SAVE_PATH': current_app.config.get('IMAGE_SAVE_PATH', 'static/images'),
            'VIDEOS_SAVE_PATH': current_app.config.get('VIDEOS_SAVE_PATH', 'static/videos')
        }
        return jsonify(settings)
    except Exception as e:
        logger.error(f"Error getting settings: {str(e)}")
        return jsonify({
            'API_KEY': '',
            'API_SECRET': '',
            'BASE_ENDPOINT': '',
            'MESSAGES_PER_PAGE': 50,
            'FETCH_INTERVAL_MINUTES': 30,
            'DEFAULT_TIMEZONE': 'Africa/Nairobi',
            'IMAGE_SAVE_PATH': 'static/images',
            'VIDEOS_SAVE_PATH': 'static/videos'
        }), 200  # Return default values instead of 500 error

@bp.route("/api/settings/api", methods=['POST'])
def save_api_settings():
    try:
        data = request.json
        # Update configuration file or environment variables
        update_config('API_KEY', data.get('API_KEY'))
        update_config('API_SECRET', data.get('API_SECRET'))
        update_config('BASE_ENDPOINT', data.get('BASE_ENDPOINT'))
        return jsonify({'status': 'success'})
    except Exception as e:
        logger.error(f"Error saving API settings: {str(e)}")
        return jsonify({'error': 'Failed to save API settings'}), 500

@bp.route("/api/settings/general", methods=['POST'])
def save_general_settings():
    try:
        data = request.json
        update_config('MESSAGES_PER_PAGE', int(data.get('MESSAGES_PER_PAGE')))
        update_config('FETCH_INTERVAL_MINUTES', int(data.get('FETCH_INTERVAL_MINUTES')))
        update_config('DEFAULT_TIMEZONE', data.get('DEFAULT_TIMEZONE'))
        return jsonify({'status': 'success'})
    except Exception as e:
        logger.error(f"Error saving general settings: {str(e)}")
        return jsonify({'error': 'Failed to save settings'}), 500

@bp.route("/api/logs/<filename>")
def get_logs(filename):
    try:
        log_path = os.path.join(current_app.config['LOG_DIR'], filename)
        with open(log_path, 'r') as f:
            return f.read()
    except Exception as e:
        logger.error(f"Error reading logs: {str(e)}")
        return jsonify({'error': 'Failed to read logs'}), 500

@bp.route("/api/logs/<filename>", methods=['DELETE'])
def clear_logs(filename):
    try:
        log_path = os.path.join(current_app.config['LOG_DIR'], filename)
        with open(log_path, 'w') as f:
            f.write('')
        return jsonify({'status': 'success'})
    except Exception as e:
        logger.error(f"Error clearing logs: {str(e)}")
        return jsonify({'error': 'Failed to clear logs'}), 500

@bp.route("/api/logs/<filename>/download")
def download_logs(filename):
    try:
        log_path = os.path.join(current_app.config['LOG_DIR'], filename)
        return send_file(log_path, as_attachment=True)
    except Exception as e:
        logger.error(f"Error downloading logs: {str(e)}")
        return jsonify({'error': 'Failed to download logs'}), 500
